/* Test of pow(). A few of exactly known results.
 */

#include <math.h>
#include <stdlib.h>

static const struct {
    union {
	long lo;
	float fl;
    } x, y, z;
} t[] = {

    /* pow (1,x) == 1	*/
    { { .fl = 1 },  { .fl = 1 },     { .fl = 1 } },
    { { .fl = 1 },  { 0x00800000 },  { .fl = 1 } },
    { { .fl = 1 },  { 0x7f7fffff },  { .fl = 1 } },
    { { .fl = 1 },  { .fl = -1 },    { .fl = 1 } },
    { { .fl = 1 },  { 0x80800000 },  { .fl = 1 } },
    { { .fl = 1 },  { 0xff7fffff },  { .fl = 1 } },
    
    /* pow (x,0) == 1	*/
    { { .fl = 1 },           { 0 },           { .fl = 1 } },
    { { .fl = 1 },           { 0x80000000 },  { .fl = 1 } },
    { { .fl = 0x00800000 },  { 0 },           { .fl = 1 } },
    { { .fl = 0x00800000 },  { 0x80000000 },  { .fl = 1 } },
    { { .fl = 0x7f7fffff },  { 0 },           { .fl = 1 } },
    { { .fl = 0x7f7fffff },  { 0x80000000 },  { .fl = 1 } },

    /* pow (0,x) == 0	*/
    { { 0 },          { .fl = 1 },     { 0 } },
    { { 0x80000000 }, { .fl = 1 },     { 0 } },
    { { 0 },          { 0x00800000 },  { 0 } },
    { { 0 },          { 0x7f7fffff },  { 0 } },

    /* result too small	*/
    { { .fl = 10 },   { .fl = -50 },  { .fl = 0 } },
    { { .fl = 100 },  { .fl = -25 },  { .fl = 0 } },
    
};

int main ()
{
    int i;
    float z;
    
    for (i = 0; i < (int)(sizeof(t) / sizeof(t[0])); i++) {
	z = pow (t[i].x.fl, t[i].y.fl);
	if (z - t[i].z.fl)	/* Subtraction is for possible -0.0	*/
	    exit (i + 1);
    }
    return 0;
}
